﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ArrowController : MonoBehaviour
{

    public float mininiumVelocity = 0.1f;
    public float damageMultipler = 1;


    private Rigidbody2D arrowRigidBody;

    private ScoreManager scoreManager;

    private bool hasImpacted;
    public bool HasImpacted
    {
        get { return hasImpacted; }
        private set
        {
            hasImpacted = value;
            if (hasImpacted)
            {
                //we don't need high precision anymore
                arrowRigidBody.collisionDetectionMode = CollisionDetectionMode2D.Discrete;
            }
        }
    }

    // Start is called before the first frame update
    void Start()
    {
        arrowRigidBody = GetComponent<Rigidbody2D>();

        GameObject obj = GameObject.Find("ScoreManager");
        if (obj != null)
        {
            scoreManager = obj.GetComponent<ScoreManager>();
        }
    }

    // Update is called once per frame
    void Update()
    {
        //arrow should loose "impactability" once it has slowed down too much
        if (!HasImpacted && arrowRigidBody.velocity.magnitude < mininiumVelocity)
        {
            HasImpacted = true;
        }
        
    }

    private void OnCollisionEnter2D(Collision2D collision)
    {
        if (!HasImpacted && !collision.collider.tag.Equals("Player"))
        {
            //make arrows stick to objects?
            FixedJoint2D joint = gameObject.AddComponent<FixedJoint2D>();
            joint.connectedBody = collision.collider.transform.GetComponent<Rigidbody2D>();

            HasImpacted = true;

            float damage = arrowRigidBody.velocity.magnitude * 10 * damageMultipler;

            bool isDead = false;
            HealthComponent hc = collision.collider.gameObject.GetComponent<HealthComponent>();
            if (hc != null)
            {
                isDead = hc.takeDamage(damage);
            }

            if (scoreManager != null)
            {
                scoreManager.AddScore(Mathf.RoundToInt(damage));
                if (isDead)
                {
                    scoreManager.AddScore(1000);
                }
            }
        }
    }
}
