﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Pathfinding;

public class EnemySpawnerController : MonoBehaviour
{
    public GameObject spawnerPrefab;
    public GameObject gameObj;
    public float spawnDelay;
    public float levelIncreaseDelay;
    public int level;

    private float spawnTimer;
    private bool canSpawn = true;

    private float levelIncreaseTimer;
    private bool canLevelIncrease;

    // Start is called before the first frame update
    void Start()
    {
        SetSpawnDelayFromLevel();

        StartCoroutine("LevelIncreaseTimer");
    }

    // Update is called once per frame
    void Update()
    {
        if (canSpawn)
        {
            GameObject playerObj = GameObject.FindGameObjectWithTag("Player");
            if (playerObj != null)
            {
                GameObject obj = Instantiate(gameObj);
                obj.transform.parent = this.transform;
                obj.transform.position = transform.position;
                obj.GetComponent<AIDestinationSetter>().target = playerObj.transform;

                canSpawn = false;
                StartCoroutine("SpawnTimer");
            }
        }

        if (canLevelIncrease)
        {
            level++;
            SetSpawnDelayFromLevel();

            canLevelIncrease = false;
            StartCoroutine("LevelIncreaseTimer");
        }

    }

    private void SetSpawnDelayFromLevel()
    {
        spawnDelay -= level * 0.05f;
        if (spawnDelay < 1f)
        {
            spawnDelay = 1f;
        }
    }

    IEnumerator SpawnTimer()
    {
        while (canSpawn == false)
        {
            spawnTimer += Time.deltaTime;
            if (spawnTimer > spawnDelay)
            {
                spawnTimer = 0.0f;
                canSpawn = true;
                break;
            }
            yield return null;
        }
    }

    IEnumerator LevelIncreaseTimer()
    {
        while (canLevelIncrease == false)
        {
            levelIncreaseTimer += Time.deltaTime;
            if (levelIncreaseTimer > levelIncreaseDelay)
            {
                levelIncreaseTimer = 0.0f;
                canLevelIncrease = true;
                break;
            }
            yield return null;
        }
    }

}
