﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class HealthComponent : MonoBehaviour
{
    public float maxHealth;
    public float health;
    public float healingRate;
    public GameObject playerUi;
    public Vector3 uiOffset;

    private GameObject healthBar_health;
    private BloodSplatterController bloodSplaterController;

    public bool IsHealing
    {
        get;
        set;
    }


    public bool IsDead
    {
        get
        {
            return health < 0;
        }
    }

    // Start is called before the first frame update
    void Start()
    {
        if (playerUi != null)
        {
            Transform t = playerUi.transform.Find("HealthBar").Find("health");
            if (t != null)
            {
                healthBar_health = t.gameObject;
            }
        }

        GameObject obj = GameObject.Find("BloodSplatters");
        if (obj != null) {
            bloodSplaterController = obj.GetComponent<BloodSplatterController>();
        }
    }

    private void OnGUI()
    {
        if (healthBar_health != null)
        {
            playerUi.transform.position = (Camera.main.WorldToScreenPoint(transform.position) + uiOffset) * 1;

            RectTransform healthRect = healthBar_health.GetComponent<RectTransform>();
            healthRect.sizeDelta = new Vector2(Mathf.Clamp((health / maxHealth) * 100, 0, 100), healthRect.sizeDelta.y);
        }
    }

    // Update is called once per frame
    void Update()
    {
        if (IsHealing && health < maxHealth)
        {
            health += healingRate;
            health = Mathf.Clamp(health, 0, maxHealth);
        }

    }
    
    public bool takeDamage(float damage)
    {
        health -= damage;
        if (IsDead)
        {
            bloodSplaterController.CreateBloodSplatter(transform.position);
            Destroy(this.gameObject);
        }
        return IsDead;
    }

}
