﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerController : MonoBehaviour
{

    public float rotationOffset = -90; // used to align player with the mouse angle
    public float rotationSpeed = 5;
    public float movementSpeed = 5;


    private float lastAngle;
    private float currentAngle;

    private Rigidbody2D rigidBody;

    private WeaponController weaponController;
    private ScoreManager scoreManager;

    // Start is called before the first frame update
    void Start()
    {
        rigidBody = GetComponent<Rigidbody2D>();
        weaponController = GetComponent<WeaponController>();

        GameObject obj = GameObject.Find("ScoreManager");
        if (obj != null)
        {
            scoreManager = obj.GetComponent<ScoreManager>();
        }

    }

    // Update is called once per frame
    void Update()
    {
        /* handle mouse aim */
        Vector3 target = Camera.main.ScreenToWorldPoint(Input.mousePosition);

        Vector3 delta = target - transform.position;

        delta.Normalize();

        if (delta.sqrMagnitude > 0.1f)
        {
            float angle = Mathf.Atan2(delta.y, delta.x) * Mathf.Rad2Deg;

            angle += rotationOffset;

            currentAngle = Mathf.LerpAngle(lastAngle, angle, Time.deltaTime * rotationSpeed);

            transform.localEulerAngles = new Vector3(transform.localEulerAngles.x,
                                          transform.localEulerAngles.y,
                                          currentAngle);

            lastAngle = currentAngle;
        }

        if (Input.GetButton("Fire1"))
        {
            weaponController.ShootArrow();
        }

        if (scoreManager != null)
        {
            weaponController.shootDelay = Mathf.Clamp(0.5f / ((scoreManager.score + 1f) / 10000f), 0.05f, 0.5f);
        }
    }

    void FixedUpdate()
    {
        /* handle player movement */
        float x = Input.GetAxis("Horizontal");
        float y = Input.GetAxis("Vertical");
        Vector3 move = new Vector3(x * movementSpeed, y * movementSpeed, 0f);
        rigidBody.velocity = move;
    }


}
